@@ -34,7 +34,7 @@ from random import randint
 from micropython import const
 from .matcher import MQTTMatcher
 
-__version__ = "7.0.2"
+__version__ = "7.1.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MiniMQTT.git"
 
 # Client-specific variables
@@ -124,7 +124,8 @@ class MQTT:
     """MQTT Client for CircuitPython.
 
     :param str broker: MQTT Broker URL or IP Address.
-    :param int port: Optional port definition, defaults to 8883.
+    :param int port: Optional port definition, defaults to MQTT_TLS_PORT if is_ssl is True,
+        MQTT_TCP_PORT otherwise.
     :param str username: Username for broker authentication.
     :param str password: Password for broker authentication.
     :param network_manager: NetworkManager object, such as WiFiManager from ESPSPI_WiFiManager.
@@ -138,6 +139,7 @@ class MQTT:
     :param int socket_timeout: How often to check socket state for read/write/connect operations,
         in seconds.
     :param int connect_retries: How many times to try to connect to broker before giving up.
+    :param class user_data: arbitrary data to pass as a second argument to the callbacks.
 
     """
 
@@ -158,6 +160,7 @@ class MQTT:
         use_binary_mode=False,
         socket_timeout=1,
         connect_retries=5,
+        user_data=None,
     ):
 
         self._socket_pool = socket_pool
@@ -175,7 +178,7 @@ class MQTT:
         self._connect_retries = connect_retries
 
         self.keep_alive = keep_alive
-        self._user_data = None
+        self._user_data = user_data
         self._is_connected = False
         self._msg_size_lim = MQTT_MSG_SZ_LIM
         self._pid = 0
@@ -252,7 +255,7 @@ class MQTT:
         if not isinstance(port, int):
             raise RuntimeError("Port must be an integer")
 
-        if port == 8883 and not self._ssl_context:
+        if port == MQTT_TLS_PORT and not self._ssl_context:
             raise RuntimeError(
                 "ssl_context must be set before using adafruit_mqtt for secure MQTT."
             )
@@ -282,7 +285,7 @@ class MQTT:
                 continue
 
             connect_host = addr_info[-1][0]
-            if port == 8883:
+            if port == MQTT_TLS_PORT:
                 sock = self._ssl_context.wrap_socket(sock, server_hostname=host)
                 connect_host = host
             sock.settimeout(timeout)
@@ -1074,16 +1077,22 @@ class MQTT:
         return self._is_connected and self._sock is not None
 
     # Logging
-    def enable_logger(self, logger, log_level=20):
-        """Enables library logging provided a logger object.
+    def enable_logger(self, log_pkg, log_level=20, logger_name="log"):
+        """Enables library logging by getting logger from the specified logging package
+        and setting its log level.
 
-        :param logger: A python logger pacakge.
+        :param log_pkg: A Python logging package.
         :param log_level: Numeric value of a logging level, defaults to INFO.
+        :param logger_name: name of the logger, defaults to "log".
+
+        :return logger object
 
         """
-        self.logger = logger.getLogger("log")
+        self.logger = log_pkg.getLogger(logger_name)
         self.logger.setLevel(log_level)
 
+        return self.logger
+
     def disable_logger(self):
         """Disables logging."""
         if not self.logger:
